"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const stream_1 = require("stream");
class PackingStream extends stream_1.Transform {
    constructor({ hasTitle }) {
        super({ objectMode: true });
        this.packingComponent = null;
        this.shouldPackTitle = hasTitle;
    }
    _transform(blockComponent, _encoding, callback) {
        if (this.shouldPackTitle) {
            this.shouldPackTitle = false;
            const titleBlockComponent = {
                type: 'title',
                text: blockComponent.text
            };
            this.push(titleBlockComponent);
            return callback();
        }
        const { indent, text } = blockComponent;
        if (this.packingComponent) {
            if (indent > this.packingComponent.indent) {
                this.packingComponent.components.push(blockComponent);
                return callback();
            }
            else {
                this.push(this.packingComponent);
                this.packingComponent = null;
            }
        }
        const isCodeBlock = text.match(/^\s*code:(.+)$/);
        const isTable = text.match(/^\s*table:(.+)$/);
        if (isCodeBlock || isTable) {
            this.packingComponent = {
                type: isCodeBlock ? 'codeBlock' : 'table',
                components: [blockComponent],
                indent
            };
            return callback();
        }
        const lineComponent = {
            type: 'line',
            component: blockComponent
        };
        this.push(lineComponent);
        return callback();
    }
    _final(callback) {
        if (this.packingComponent)
            this.push(this.packingComponent);
        return callback();
    }
}
exports.default = PackingStream;
//# sourceMappingURL=PackingBlockStream.js.map